Benchmarking Suite Scheduler
============================
This component is a simple scheduler to execute and repeat Benchmarking Suite tests after a given time interval. The scheduling is read from a MongoDB collection.

Documentation
=============
User and technical documentation is available at http://benchmarking-suite.readthedocs.io/.

Support
=======

For bugs, enhancements or support go to https://github.com/benchmarking-suite/benchsuite-issues/issues/.

Legal
=====
The Benchmarking Suite is released under the `Apache 2.0 <https://www.apache.org/licenses/LICENSE-2.0>`_ license.

Copyright © 2014-2018 Engineering Ingegneria Informatica S.p.A. All rights reserved.

+------------------------------------------------------------------+------------------------------------------------------------------------------------------------------------------------------+
| .. image:: http://www.consilium.europa.eu/images/img_flag-eu.gif |This work has received partial funding from the European Commission under grant agreements No. FP7-317859 and No. H2020-732258|
+------------------------------------------------------------------+------------------------------------------------------------------------------------------------------------------------------+

